pub struct OrganizationInviteCryptoBundle {
pub invite_key: InviteKeyData,
pub sealed_invite_key_envelope: InviteKeyEnvelope,
}Expand description
The cryptographic bundle returned when generating an organization member invite link.
invite_key: raw invite key encoded as base64Url. MUST NOT be sent to the server.sealed_invite_key_envelope: invite key sealed with the organization key, serialized as an EncString. Safe to send to the server.
Fields
invite_key: InviteKeyDataRaw invite key. CRITICAL: MUST NOT be sent to the server.
sealed_invite_key_envelope: InviteKeyEnvelopeInvite key sealed with the organization key. Safe to send to the server.